@@ -1,7 +1,7 @@
 /* poppler-qt.h: qt interface to poppler
  * Copyright (C) 2005, Net Integration Technologies, Inc.
  * Copyright (C) 2005, 2007, Brad Hards <bradh@frogmouth.net>
- * Copyright (C) 2005-2015, 2017, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2005-2015, 2017, 2018, Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2005, Stefan Kebekus <stefan.kebekus@math.uni-koeln.de>
  * Copyright (C) 2006-2011, Pino Toscano <pino@kde.org>
  * Copyright (C) 2009 Shawn Rutledge <shawn.t.rutledge@gmail.com>
@@ -960,6 +960,13 @@ delete it;
 	**/
 	QString label() const;
 	
+	/**
+	   Returns the index of the page.
+
+	 \since 0.70
+	**/
+	int index() const;
+
     private:
 	Q_DISABLE_COPY(Page)
 
@@ -1962,7 +1969,14 @@ height = dummy.height();
     /**
        Conversion from PDF date string format to QDateTime
     */
-    POPPLER_QT5_EXPORT QDateTime convertDate( char *dateString );
+    POPPLER_QT5_EXPORT Q_DECL_DEPRECATED QDateTime convertDate( char *dateString );
+
+    /**
+       Conversion from PDF date string format to QDateTime
+
+       \since 0.64
+    */
+    POPPLER_QT5_EXPORT QDateTime convertDate( const char *dateString );
 
     /**
        Whether the color management functions are available.
